==> aws-cdk-scala_2.12-0.5.1-sources.jar: io/burkard/cdk/services/codebuild/GitHubEnterpriseSourceProps.scala <==
package io.burkard.cdk.services.codebuild

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object GitHubEnterpriseSourceProps {

  def apply(
    httpsCloneUrl: String,
    reportBuildStatus: Option[Boolean] = None,
    identifier: Option[String] = None,
    webhookFilters: Option[List[_ <: software.amazon.awscdk.services.codebuild.FilterGroup]] = None,
    branchOrRef: Option[String] = None,
    ignoreSslErrors: Option[Boolean] = None,
    cloneDepth: Option[Number] = None,
    webhookTriggersBatchBuild: Option[Boolean] = None,
    webhook: Option[Boolean] = None,
    fetchSubmodules: Option[Boolean] = None
  ): software.amazon.awscdk.services.codebuild.GitHubEnterpriseSourceProps =
    (new software.amazon.awscdk.services.codebuild.GitHubEnterpriseSourceProps.Builder)
      .httpsCloneUrl(httpsCloneUrl)
      .reportBuildStatus(reportBuildStatus.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .identifier(identifier.orNull)
      .webhookFilters(webhookFilters.map(_.asJava).orNull)
      .branchOrRef(branchOrRef.orNull)
      .ignoreSslErrors(ignoreSslErrors.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .cloneDepth(cloneDepth.orNull)
      .webhookTriggersBatchBuild(webhookTriggersBatchBuild.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .webhook(webhook.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .fetchSubmodules(fetchSubmodules.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .build()
}

==> aws-cdk-scala_3-0.22.0-sources.jar: io/burkard/cdk/services/codebuild/GitHubEnterpriseSourceProps.scala <==
package io.burkard.cdk.services.codebuild

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object GitHubEnterpriseSourceProps {

  def apply(
    httpsCloneUrl: String,
    buildStatusContext: Option[String] = None,
    reportBuildStatus: Option[Boolean] = None,
    identifier: Option[String] = None,
    webhookFilters: Option[List[_ <: software.amazon.awscdk.services.codebuild.FilterGroup]] = None,
    branchOrRef: Option[String] = None,
    buildStatusUrl: Option[String] = None,
    ignoreSslErrors: Option[Boolean] = None,
    cloneDepth: Option[Number] = None,
    webhookTriggersBatchBuild: Option[Boolean] = None,
    webhook: Option[Boolean] = None,
    fetchSubmodules: Option[Boolean] = None
  ): software.amazon.awscdk.services.codebuild.GitHubEnterpriseSourceProps =
    (new software.amazon.awscdk.services.codebuild.GitHubEnterpriseSourceProps.Builder)
      .httpsCloneUrl(httpsCloneUrl)
      .buildStatusContext(buildStatusContext.orNull)
      .reportBuildStatus(reportBuildStatus.map(Boolean.box).orNull)
      .identifier(identifier.orNull)
      .webhookFilters(webhookFilters.map(_.asJava).orNull)
      .branchOrRef(branchOrRef.orNull)
      .buildStatusUrl(buildStatusUrl.orNull)
      .ignoreSslErrors(ignoreSslErrors.map(Boolean.box).orNull)
      .cloneDepth(cloneDepth.orNull)
      .webhookTriggersBatchBuild(webhookTriggersBatchBuild.map(Boolean.box).orNull)
      .webhook(webhook.map(Boolean.box).orNull)
      .fetchSubmodules(fetchSubmodules.map(Boolean.box).orNull)
      .build()
}
